"""ModelViewSet method name constants."""

MODELVIEWSET_CREATE_METHOD_NAME = "create"
MODELVIEWSET_PARTIAL_UPDATE_METHOD_NAME = "partial_update"
MODELVIEWSET_UPDATE_METHOD_NAME = "update"
MODELVIEWSET_DELETE_METHOD_NAME = "delete"
MODELVIEWSET_GET_METHOD_NAME = "get"
MODELVIEWSET_DETAILS_METHOD_NAME = "retrieve"
MODELVIEWSET_LIST_METHOD_NAME = "list"
