DEBUG="True"
SECRET_KEY="change-me-to-a-real-secret-key"
ALLOWED_HOSTS="localhost,127.0.0.1"
CORS_ALLOWED_ORIGINS="http://localhost:5173"
CSRF_TRUSTED_ORIGINS="http://localhost:5173"

# Auth
SUPERUSER_EMAIL="admin@example.com"
SUPERUSER_PASSWORD="change-me"
ACCESS_TOKEN_LIFETIME_MINUTES="60"
REFRESH_TOKEN_LIFETIME_MINUTES="1440"

# Database
DB_NAME="{{ project_name }}_db"
DB_USER="superuser"
DB_PASSWORD="password"
DB_HOST="localhost"
DB_PORT="5432"

# Celery
{% if platform == "aws-eb" -%}
CELERY_BROKER_URL="sqs://x:x@localhost:9324/"
AWS_REGION_NAME="elasticmq"
{% else -%}
CELERY_BROKER_URL="redis://localhost:6379/0"
{% endif -%}
CELERY_TASK_DEFAULT_QUEUE="{{ project_name }}-local"
{% if platform == "aws-eb" %}

# S3
AWS_STORAGE_BUCKET_NAME="{{ project_name }}-development"
AWS_S3_ENDPOINT_URL="http://localhost:9000"
AWS_ACCESS_KEY_ID="minio"
AWS_SECRET_ACCESS_KEY="minio123"
AWS_S3_CUSTOM_DOMAIN="localhost:9000"
USE_S3="False"

# Log Whisperer (optional — EB environment variables)
# LOG_WHISPERER_ENABLED="false"
# LOG_WHISPERER_CRON_INTERVAL="15"
# LOG_WHISPERER_MIN_SEVERITY="WARN"
# LOG_WHISPERER_BASELINE_MINUTES="30"
# LOG_WHISPERER_NTFY_TOPIC=""
# LOG_WHISPERER_TELEGRAM_TOKEN=""
# LOG_WHISPERER_TELEGRAM_CHAT=""
{% endif %}
