services:
  postgres:
    image: postgres:16
    environment:
      POSTGRES_DB: {{ project_name }}_db
      POSTGRES_USER: superuser
      POSTGRES_PASSWORD: password
    ports:
      - "5432:5432"
    volumes:
      - pgdata:/var/lib/postgresql/data

  redis:
    image: redis:7-alpine
    ports:
      - "6379:6379"

volumes:
  pgdata:
